#
# spec file for package dcmtk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libdcmtk3_6

Name:           dcmtk
Version:        3.6.2
Release:        lp151.2.5
Summary:        DICOM Toolkit
License:        BSD-3-Clause and Apache-2.0
Group:          Productivity/Scientific/Other
Url:            http://dicom.offis.de/dcmtk.php.en
Source0:        ftp://dicom.offis.de/pub/dicom/offis/software/dcmtk/dcmtk362/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE dcmtk-3.6.0-0002-Install-libs-in-the-correct-arch-dir.patch asterios.dramis@gmail.com -- Install libs in the correct arch dir
Patch1:         dcmtk-3.6.0-0002-Install-libs-in-the-correct-arch-dir.patch
# PATCH-FIX-OPENSUSE dcmtk-fix-DCMTKTargets.cmake.patch -- Do not track executables to be able to use dcmtk-devel without dcmtk package
Patch2:         dcmtk-fix-DCMTKTargets.cmake.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libtiff-devel
BuildRequires:  tcpd-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libxml-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
DCMTK is a collection of libraries and applications implementing large
parts the DICOM standard.

%package devel
Summary:        Development files for dcmtk
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package provides development libraries and headers needed to build
software using dcmtk.

%package -n %{libname}
Summary:        DICOM Toolkit
Group:          System/Libraries

%description -n %{libname}
DCMTK is a collection of libraries and applications implementing large
parts the DICOM standard.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
mkdir build
cd build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
 cmake \
 -DCMAKE_INSTALL_PREFIX=%{_prefix} \
 -DINSTALL_DOCDIR=%{_docdir}/dcmtk \
 -DINSTALL_HTMDIR=%{_docdir}/dcmtk/html \
 -DBUILD_SHARED_LIBS=ON \
 %if "%{_lib}" == "lib64"
  -DLIB_SUFFIX=64 \
 %endif
 -DDCMTK_WITH_XML=ON \
 -DDCMTK_WITH_OPENSSL=ON \
 -DDCMTK_WITH_SNDFILE=ON \
 -DDCMTK_WITH_ZLIB=ON \
 -DDCMTK_WITH_CHARLS=ON \
 -DCMAKE_BUILD_TYPE=release ..
make %{?_smp_mflags} VERBOSE=1
cd ..

%install
cd build
%make_install
cd ..

# Remove zero-length file (fix rpmlint warning)
rm -f %{buildroot}%{_datadir}/dcmtk/wlistdb/OFFIS/lockfile

# Move configuration files from /usr/etc to /etc/
mv %{buildroot}%{_prefix}/etc %{buildroot}

# Move doc files from /usr/share/doc/dcmtk to /usr/share/doc/packages/dcmtk/
mkdir %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}

# Install README file to documentation
install -pm 0644 README %{buildroot}%{_docdir}/dcmtk/

%fdupes -s %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%dir %{_sysconfdir}/dcmtk
%config(noreplace) %{_sysconfdir}/dcmtk/*.cfg
%{_bindir}/*
%{_datadir}/dcmtk/
%doc %{_docdir}/dcmtk/
%doc %{_mandir}/man1/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/dcmtk/
%{_libdir}/*.so
%{_libdir}/cmake/dcmtk/

%files -n %{libname}
%defattr(-,root,root,-)
%{_libdir}/*.so.3.6*
%{_libdir}/*.so.12

%changelog
* Sat Nov 18 2017 christophe@krop.fr
- Fix dcmtk-fix-DCMTKTargets.cmake.patch
* Fri Nov 17 2017 guillaume@opensuse.org
- Add dcmtk-fix-DCMTKTargets.cmake.patch to fix usage of 'dcmtk-devel'
  without 'dcmtk' package
* Tue Jul 25 2017 tittiatcoke@gmail.com
- Update to version 3.6.2
  * See DOCS/Changes.362 for more information
- Build against the internal CharLS library. Only version 1.0 is
  supported and Factory offers version 2.0
  * Drop patches:
  - dcmtk-3.6.0-0004-Use-system-charls.patch
  - dcmtk-3.6.0-0003-Removed-bundled-libcharl-reference-in-dcmjpls.patch
  - dcmtk-3.6.0-0005-Fixed-includes-for-CharLS-1.0.patch
- Drop patches due to updated build system and upstream integration:
  * dcmtk-3.6.0-0001-Added-soname-information-for-all-targets.patch
  * dcmtk-3.6.0-0006-Added-optional-support-for-building-shared-libraries.patch
  * dcmtk-3.6.0-0007-Add-soname-generation-for-modules-which-are-not-in-D.patch
  * dcmtk-3.6.0.diff
  * gcc-4.7_fix.patch
* Thu Aug 30 2012 pgajdos@suse.com
- require libpng-devel instead of libpng14-compat-devel;
  libpng14-compat-devel is now default libpng-devel provider for
  factory; moreover dcmtk builds correctly with libpng15-devel too
* Sun Mar 18 2012 asterios.dramis@gmail.com
- Added a patch (gcc-4.7_fix.patch) to fix compilation with gcc-4.7.
- Remove zero-length file /usr/share/dcmtk/wlistdb/OFFIS/lockfile (fix rpmlint
  warning).
* Tue Dec 13 2011 coolo@suse.com
- fix last change
* Mon Dec 12 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed libdcmtk3 subpackage name to libdcmtk3_6 which is the correct one
    according to openSUSE shared library packaging policy.
* Sun Dec 11 2011 asterios.dramis@gmail.com
- Added seven patches (taken from Fedora) to make the package build shared
  libraries (using cmake) and link to the system "CharLS" library instead of
  the internal copy:
  + dcmtk-3.6.0-0001-Added-soname-information-for-all-targets.patch
  + dcmtk-3.6.0-0002-Install-libs-in-the-correct-arch-dir.patch
  + dcmtk-3.6.0-0003-Removed-bundled-libcharl-reference-in-dcmjpls.patch
  + dcmtk-3.6.0-0004-Use-system-charls.patch
  + dcmtk-3.6.0-0005-Fixed-includes-for-CharLS-1.0.patch
  + dcmtk-3.6.0-0006-Added-optional-support-for-building-shared-libraries.patch
  + dcmtk-3.6.0-0007-Add-soname-generation-for-modules-which-are-not-in-D.patch
- Added a patch "dcmtk-3.6.0.diff" to fix libraries linking.
- Spec file updates:
  * Changed License: entry to SPDX style. Removed "AS IS" to fix rpmlint
    warning "invalid-license".
  * Adapted spec file to the cmake usage and building of shared libraries.
    Added a libdcmtk3 subpackage.
  * Added CharLS-devel in BuildRequires:.
* Thu Sep 22 2011 toddrme2178@gmail.com
- Added build of development files.  Without these other software
  can't make use of this.
* Mon Aug 29 2011 toddrme2178@gmail.com
- Added ASL-2.0 to the spec file license tag (see bnc #711187)
* Thu Aug  4 2011 toddrme2178@gmail.com
- Created proper spec file with macors and a real %%files section
- Moved changes to a .changes file
- Removed tests for other distributions
- Switched Url to the source of the tarball rather than the source
  of the original rpm
* Sat Aug 23 2008 stkaopen@gmx.at
- packaged dcmtk version 3.5.4 using the buildservice spec file wizard
